==> twilio_chat_plugin-0.0.5.tar.gz: example/lib/pages/channel.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:intl/intl.dart';
import 'package:twilio_chat_plugin_example/models/thread.dart';
import 'package:twilio_chat_plugin_example/pages/widgets/chat_room_app_bar.dart';
import 'package:twilio_chat_plugin_example/pages/widgets/chat_thread.dart';
import 'package:twilio_chat_plugin_example/pages/widgets/send_message_bar.dart';
import 'package:twilio_chat_plugin/twilio_chat_plugin.dart';
import 'package:twilio_chat_plugin_example/shared/helpers/twilio.dart';
import "package:collection/collection.dart";

class ChannelPage extends StatefulWidget {
  final Channel channel;

  const ChannelPage({Key key, this.channel}) : super(key: key);
  @override
  _ChannelPageState createState() => _ChannelPageState();
}

class _ChannelPageState extends State<ChannelPage>
    with TickerProviderStateMixin {
  final List<ChatThread> _chatThreads = [];
  bool _isJoined = false;

  @override
  void initState() {
    super.initState();
    retrieveRecentMessages();
    widget.channel.attachListener();
    if (widget.channel.members.membersList != null) {
      setState(() {
        _isJoined = widget.channel.members.membersList
                .where((m) => m.identity == TwilioHelper.chatClient.myIdentity)
                .length >
            0;
      });
    }
  }

  retrieveRecentMessages() async {
    final messagesList =
        await widget.channel.getMostRecentMessagesByChannelSID(500);
    TwilioHelper.channel.onMessageAdded.listen((data) {
      final m = data.message;
      final thread = Thread(
        fromSelf: m.author == TwilioHelper.chatClient.myIdentity,
        message: m.messageBody,
        dateCreated: m.dateCreated,
      );
      final ct = _buildChatThread(thread);
      _chatThreads.add(ct);

      setState(() {});
    });

    TwilioHelper.chatClient.onChannelJoined.listen((data) {
      if (data.channel.sid == widget.channel.sid) {
        setState(() {
          _isJoined = true;
        });
      }
    });
    final threads = messagesList
        .map((m) => Thread(
              fromSelf: m.author == TwilioHelper.chatClient.myIdentity,
              message: m.messageBody,
              dateCreated: m.dateCreated,
            ))
        .toList();
    threads.forEach((thread) {
      final ct = _buildChatThread(thread);
      _chatThreads.add(ct);
      ct.animationController.forward();
    });
    setState(() {});
  }

  ChatThread _buildChatThread(Thread thread) {
    final ct = ChatThread(
        thread,
        AnimationController(
          vsync: this,
          duration: Duration(milliseconds: 250),
        ),
        thread.dateCreated);

    return ct;
  }

  @override
  void dispose() {
    TwilioHelper.channel.detachListener();
    super.dispose();
  }

  Widget _buildMessageDisplay() {
    final messagesGroupByDate = groupBy(_chatThreads,
        (obj) => DateFormat('yyyy-MM-dd').format(obj.dateCreated));
    return ListView.builder(
      itemCount: messagesGroupByDate.keys.toList().length,
      reverse: true,
      itemBuilder: (context, index) {
        final messagesGroupByDateList = messagesGroupByDate.keys.toList();
        messagesGroupByDateList.sort((a, b) => b.compareTo(a));
        final date = messagesGroupByDateList[index];
        final mg = messagesGroupByDate[date];
        mg.sort((a, b) => a.dateCreated.compareTo(b.dateCreated));

        final cts = mg.map((ct) => Column(children: [
              ct,
              SizedBox(
                height: 8.0,
              ),
            ]));
        return Column(
          children: [
            SizedBox(
              height: 8.0,
            ),
            Text(
              date,
              style: TextStyle(color: Colors.grey[700]),
            ),
            SizedBox(
              height: 16.0,
            ),
            ...cts,
          ],
        );
      },
    );
  }

  void _handleSubmitted(String text) {
    final ct = _buildChatThread(Thread(
      fromSelf: true,
      message: text,
      dateCreated: DateTime.now(),
    ));

    widget.channel.sendMessagesByChannelSID(text);

    ct.animationController.forward();
  }

  void _handleJoinChannel() async {
    widget.channel.joinChannel();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Color(0xFFECE5DD),
      appBar:
          buildChatRoomAppBar(Icon(Icons.person), widget.channel.friendlyName),
      body: Center(
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: 10),
          child: Column(
            children: <Widget>[
              Expanded(
                child: _buildMessageDisplay(),
              ),
              SizedBox(height: 20),
              SendMessageBar(_handleSubmitted, _isJoined, _handleJoinChannel),
              SizedBox(height: 20),
            ],
          ),
        ),
      ),
    );
  }
}

==> twilio_chat_plugin-0.0.6.tar.gz: example/lib/pages/channel.dart <==
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:intl/intl.dart';
import 'package:twilio_chat_plugin_example/models/thread.dart';
import 'package:twilio_chat_plugin_example/pages/widgets/chat_room_app_bar.dart';
import 'package:twilio_chat_plugin_example/pages/widgets/chat_thread.dart';
import 'package:twilio_chat_plugin_example/pages/widgets/send_message_bar.dart';
import 'package:twilio_chat_plugin/twilio_chat_plugin.dart';
import 'package:twilio_chat_plugin_example/shared/helpers/twilio.dart';
import "package:collection/collection.dart";

class ChannelPage extends StatefulWidget {
  final Channel channel;

  const ChannelPage({Key key, this.channel}) : super(key: key);
  @override
  _ChannelPageState createState() => _ChannelPageState();
}

class _ChannelPageState extends State<ChannelPage>
    with TickerProviderStateMixin {
  final List<ChatThread> _chatThreads = [];
  bool _isJoined = false;

  @override
  void initState() {
    super.initState();
    retrieveRecentMessages();
    widget.channel.attachListener();
    if (widget.channel.members.membersList != null) {
      setState(() {
        _isJoined = widget.channel.members.membersList
                .where((m) => m.identity == TwilioHelper.chatClient.myIdentity)
                .length >
            0;
      });
    }
  }

  retrieveRecentMessages() async {
    final messagesList =
        await widget.channel.getMostRecentMessagesByChannelSID(500);
    TwilioHelper.channel.onMessageAdded.listen((data) {
      final m = data.message;
      final thread = Thread(
        fromSelf: m.author == TwilioHelper.chatClient.myIdentity,
        message: m.messageBody,
        dateCreated: m.dateCreated,
      );
      final ct = _buildChatThread(thread);
      _chatThreads.add(ct);
      ct.animationController.forward();
      setState(() {});
    });

    TwilioHelper.chatClient.onChannelAdded.listen((data) {
      if (data.channel.sid == widget.channel.sid) {
        setState(() {
          _isJoined = true;
        });
      }
    });
    final threads = messagesList
        .map((m) => Thread(
              fromSelf: m.author == TwilioHelper.chatClient.myIdentity,
              message: m.messageBody,
              dateCreated: m.dateCreated,
            ))
        .toList();
    threads.forEach((thread) {
      final ct = _buildChatThread(thread);
      _chatThreads.add(ct);
      ct.animationController.forward();
    });
    setState(() {});
  }

  ChatThread _buildChatThread(Thread thread) {
    final ct = ChatThread(
        thread,
        AnimationController(
          vsync: this,
          duration: Duration(milliseconds: 250),
        ),
        thread.dateCreated);

    return ct;
  }

  @override
  void dispose() {
    TwilioHelper.channel.detachListener();
    super.dispose();
  }

  Widget _buildMessageDisplay() {
    final messagesGroupByDate = groupBy(_chatThreads,
        (obj) => DateFormat('yyyy-MM-dd').format(obj.dateCreated));
    return ListView.builder(
      itemCount: messagesGroupByDate.keys.toList().length,
      reverse: true,
      itemBuilder: (context, index) {
        final messagesGroupByDateList = messagesGroupByDate.keys.toList();
        messagesGroupByDateList.sort((a, b) => b.compareTo(a));
        final date = messagesGroupByDateList[index];
        final mg = messagesGroupByDate[date];
        mg.sort((a, b) => a.dateCreated.compareTo(b.dateCreated));

        final cts = mg.map((ct) => Column(children: [
              ct,
              SizedBox(
                height: 8.0,
              ),
            ]));
        return Column(
          children: [
            SizedBox(
              height: 8.0,
            ),
            Text(
              date,
              style: TextStyle(color: Colors.grey[700]),
            ),
            SizedBox(
              height: 16.0,
            ),
            ...cts,
          ],
        );
      },
    );
  }

  void _handleSubmitted(String text) {
    final ct = _buildChatThread(Thread(
      fromSelf: true,
      message: text,
      dateCreated: DateTime.now(),
    ));

    widget.channel.sendMessagesByChannelSID(text);
    ct.animationController.forward();
  }

  void _handleJoinChannel() async {
    widget.channel.joinChannel();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Color(0xFFECE5DD),
      appBar:
          buildChatRoomAppBar(Icon(Icons.person), widget.channel.friendlyName),
      body: Center(
        child: Container(
          padding: EdgeInsets.symmetric(horizontal: 10),
          child: Column(
            children: <Widget>[
              Expanded(
                child: _buildMessageDisplay(),
              ),
              SizedBox(height: 20),
              SendMessageBar(_handleSubmitted, _isJoined, _handleJoinChannel),
              SizedBox(height: 20),
            ],
          ),
        ),
      ),
    );
  }
}
